@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2012-2015 Meltytech, LLC
- * Author: Dan Dennedy <dan@dennedy.org>
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +20,8 @@
 
 #include <QDialog>
 
+class QDialogButtonBox;
+
 namespace Ui {
 class TextViewerDialog;
 }
@@ -30,15 +31,17 @@ class TextViewerDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit TextViewerDialog(QWidget *parent = 0);
+    explicit TextViewerDialog(QWidget *parent = 0, bool forMltXml = false);
     ~TextViewerDialog();
-    void setText(const QString &s);
+    void setText(const QString &s, bool scroll = false);
+    QDialogButtonBox *buttonBox() const;
 
 private slots:
     void on_buttonBox_accepted();
 
 private:
     Ui::TextViewerDialog *ui;
+    bool m_forMltXml;
 };
 
 #endif // TEXTVIEWERDIALOG_H
