@@ -20,12 +20,12 @@
 
 #include "settings.h"
 
+#include <MltProperties.h>
 #include <QDockWidget>
 #include <QDomElement>
-#include <QStandardItemModel>
 #include <QSortFilterProxyModel>
+#include <QStandardItemModel>
 #include <QStringList>
-#include <MltProperties.h>
 
 class QTreeWidgetItem;
 class QTemporaryFile;
@@ -38,7 +38,7 @@ namespace Mlt {
 class Service;
 class Producer;
 class Filter;
-}
+} // namespace Mlt
 
 class PresetsProxyModel : public QSortFilterProxyModel
 {
@@ -109,7 +109,7 @@ private slots:
 
     void on_audioCodecCombo_currentIndexChanged(int index);
 
-    void setAudioChannels( int channels );
+    void setAudioChannels(int channels);
 
     void on_widthSpinner_editingFinished();
 
@@ -169,11 +169,18 @@ private:
     Mlt::Properties *collectProperties(int realtime, bool includeProfile = false);
     void collectProperties(QDomElement &node, int realtime);
     void setSubtitleProperties(QDomElement &node, Mlt::Producer *service);
-    QPoint addConsumerElement(Mlt::Producer *service, QDomDocument &dom, const QString &target,
-                              int realtime, int pass);
-    MeltJob *convertReframe(Mlt::Producer *service, QTemporaryFile *tmp, const QString &target,
-                            int realtime, int pass, const QThread::Priority priority);
-    MeltJob *createMeltJob(Mlt::Producer *service, const QString &target, int realtime, int pass = 0,
+    QPoint addConsumerElement(
+        Mlt::Producer *service, QDomDocument &dom, const QString &target, int realtime, int pass);
+    MeltJob *convertReframe(Mlt::Producer *service,
+                            QTemporaryFile *tmp,
+                            const QString &target,
+                            int realtime,
+                            int pass,
+                            const QThread::Priority priority);
+    MeltJob *createMeltJob(Mlt::Producer *service,
+                           const QString &target,
+                           int realtime,
+                           int pass = 0,
                            const QThread::Priority priority = Settings.jobPriority());
     void runMelt(const QString &target, int realtime = -1);
     void enqueueAnalysis();
