@@ -19,9 +19,11 @@
 
 #include "Logger.h"
 #include "actions.h"
+#include "dialogs/speechdialog.h"
 #include "dialogs/subtitletrackdialog.h"
 #include "dialogs/transcribeaudiodialog.h"
 #include "jobqueue.h"
+#include "jobs/kokorodokijob.h"
 #include "jobs/meltjob.h"
 #include "jobs/whisperjob.h"
 #include "mainwindow.h"
@@ -37,6 +39,7 @@
 #include <QAction>
 #include <QApplication>
 #include <QComboBox>
+#include <QFileInfo>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QHeaderView>
@@ -191,6 +194,9 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     mainMenu->addAction(Actions["subtitleBurnInAction"]);
     mainMenu->addAction(Actions["subtitleGenerateTextAction"]);
     mainMenu->addAction(Actions["subtitleSpeechToTextAction"]);
+#ifdef EXTERNAL_LAUNCHERS
+    mainMenu->addAction(Actions["subtitleTextToSpeechAction"]);
+#endif
     mainMenu->addAction(Actions["subtitleTrackTimelineAction"]);
     mainMenu->addAction(Actions["subtitleShowPrevNextAction"]);
 
@@ -260,6 +266,13 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     button->setAutoRaise(true);
     toolbar->addWidget(button);
 
+#ifdef EXTERNAL_LAUNCHERS
+    button = new QToolButton;
+    button->setDefaultAction(Actions["subtitleTextToSpeechAction"]);
+    button->setAutoRaise(true);
+    toolbar->addWidget(button);
+#endif
+
     vboxLayout->addWidget(toolbar);
 
     QFontMetrics fm(font());
@@ -407,7 +420,7 @@ void SubtitlesDock::setupActions()
     Actions.add("subtitleMoveAction", action, windowTitle());
 
     action = new QAction(tr("Burn In Subtitles on Output"), this);
-    action->setToolTip(tr("Create or edit a Burn In Subtitles filter on the timeline output."));
+    action->setToolTip(tr("Create or edit a Subtitle Burn In filter on the timeline output."));
     action->setIcon(QIcon::fromTheme("font", QIcon(":/icons/oxygen/32x32/actions/font.png")));
     connect(action, &QAction::triggered, this, &SubtitlesDock::burnInOnTimeline);
     Actions.add("subtitleBurnInAction", action, windowTitle());
@@ -425,6 +438,15 @@ void SubtitlesDock::setupActions()
     connect(action, &QAction::triggered, this, &SubtitlesDock::speechToText);
     Actions.add("subtitleSpeechToTextAction", action, windowTitle());
 
+#ifdef EXTERNAL_LAUNCHERS
+    action = new QAction(tr("Text to Speech..."), this);
+    action->setToolTip(tr("Convert the current subtitle track to spoken audio."));
+    action->setIcon(
+        QIcon::fromTheme("text-speak", QIcon(":/icons/oxygen/32x32/actions/text-speak.png")));
+    connect(action, &QAction::triggered, this, &SubtitlesDock::textToSpeech);
+    Actions.add("subtitleTextToSpeechAction", action, windowTitle());
+#endif
+
     action = new QAction(tr("Track Timeline Cursor"), this);
     action->setToolTip(tr("Track the timeline cursor"));
     action->setCheckable(true);
@@ -989,6 +1011,9 @@ void SubtitlesDock::updateActionAvailablity()
         Actions["subtitleBurnInAction"]->setEnabled(false);
         Actions["subtitleGenerateTextAction"]->setEnabled(false);
         Actions["subtitleSpeechToTextAction"]->setEnabled(false);
+#ifdef EXTERNAL_LAUNCHERS
+        Actions["subtitleTextToSpeechAction"]->setEnabled(false);
+#endif
     } else {
         m_addToTimelineLabel->setVisible(false);
         Actions["subtitleCreateEditItemAction"]->setEnabled(true);
@@ -997,6 +1022,9 @@ void SubtitlesDock::updateActionAvailablity()
         Actions["SubtitleImportAction"]->setEnabled(true);
         Actions["subtitleAddItemAction"]->setEnabled(true);
         Actions["subtitleSpeechToTextAction"]->setEnabled(true);
+#ifdef EXTERNAL_LAUNCHERS
+        Actions["subtitleTextToSpeechAction"]->setEnabled(true);
+#endif
         if (m_model->trackCount() == 0) {
             Actions["subtitleRemoveTrackAction"]->setEnabled(false);
             Actions["SubtitleExportAction"]->setEnabled(false);
@@ -1006,6 +1034,9 @@ void SubtitlesDock::updateActionAvailablity()
             Actions["subtitleSetEndAction"]->setEnabled(false);
             Actions["subtitleBurnInAction"]->setEnabled(false);
             Actions["subtitleGenerateTextAction"]->setEnabled(false);
+#ifdef EXTERNAL_LAUNCHERS
+            Actions["subtitleTextToSpeechAction"]->setEnabled(false);
+#endif
         } else {
             Actions["subtitleRemoveTrackAction"]->setEnabled(true);
             Actions["SubtitleExportAction"]->setEnabled(true);
@@ -1313,3 +1344,46 @@ void SubtitlesDock::speechToText()
     tmpSrt->setParent(whisperJob);
     JOBS.add(whisperJob);
 }
+
+void SubtitlesDock::textToSpeech()
+{
+    if (!m_model || m_model->trackCount() == 0 || !KokorodokiJob::checkDockerImage(this)) {
+        return;
+    }
+    int trackIndex = m_trackCombo->currentIndex();
+    if (trackIndex < 0) {
+        return;
+    }
+    if (m_model->itemCount(trackIndex) == 0) {
+        return;
+    }
+
+    m_speechDialog.reset(new SpeechDialog(this));
+    if (m_speechDialog->exec() != QDialog::Accepted)
+        return;
+
+    KokorodokiJob::prepareAndRun(this, [=]() {
+        const auto outFile = m_speechDialog->outputFile();
+        if (outFile.isEmpty())
+            return;
+        QFileInfo outInfo(outFile);
+        auto srtFile = new QTemporaryFile(outInfo.dir().filePath("XXXXXX.srt"));
+        if (!srtFile->open()) {
+            LOG_ERROR() << "Failed to create temp srt file" << srtFile->fileName();
+            srtFile->deleteLater();
+            return;
+        }
+        srtFile->close();
+        m_model->exportSubtitles(srtFile->fileName(), trackIndex);
+
+        // Export current track subtitles to SRT.
+        const auto lang = m_speechDialog->languageCode();
+        const auto voice = m_speechDialog->voiceCode();
+        const auto spd = m_speechDialog->speed();
+        auto job = new KokorodokiJob(srtFile->fileName(), outFile, lang, voice, spd);
+
+        srtFile->setParent(job); // auto-delete with job
+        job->setPostJobAction(new OpenPostJobAction(outFile, outFile, QString()));
+        JOBS.add(job);
+    });
+}
