@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2024 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,21 +16,25 @@
  */
 
 #include "meltjob.h"
-#include <QFile>
-#include <QFileInfo>
-#include <QDir>
-#include <QIODevice>
-#include <QApplication>
-#include <QAction>
-#include <QDialog>
-#include <QDir>
-#include <QTimer>
-#include <Logger.h>
-#include "mainwindow.h"
+
+#include "Logger.h"
 #include "dialogs/textviewerdialog.h"
+#include "mainwindow.h"
 #include "util.h"
 
-MeltJob::MeltJob(const QString &name, const QString &xml, int frameRateNum, int frameRateDen,
+#include <QAction>
+#include <QApplication>
+#include <QDialog>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QIODevice>
+#include <QTimer>
+
+MeltJob::MeltJob(const QString &name,
+                 const QString &xml,
+                 int frameRateNum,
+                 int frameRateDen,
                  QThread::Priority priority)
     : AbstractJob(name, priority)
     , m_isStreaming(false)
@@ -38,15 +42,17 @@ MeltJob::MeltJob(const QString &name, const QString &xml, int frameRateNum, int
     , m_currentFrame(0)
     , m_useMultiConsumer(false)
 {
+    setTarget(name);
     if (!xml.isEmpty()) {
         QAction *action = new QAction(tr("View XML"), this);
         action->setToolTip(tr("View the MLT XML for this job"));
         connect(action, SIGNAL(triggered()), this, SLOT(onViewXmlTriggered()));
         m_standardActions << action;
         m_xml.reset(Util::writableTemporaryFile(name, "shotcut-XXXXXX.mlt"));
-        m_xml->open();
-        m_xml->write(xml.toUtf8());
-        m_xml->close();
+        if (m_xml->open()) {
+            m_xml->write(xml.toUtf8());
+            m_xml->close();
+        }
     } else {
         // Not an EncodeJob
         QAction *action = new QAction(tr("Open"), this);
@@ -84,7 +90,10 @@ void MeltJob::onShowInFilesTriggered()
     MAIN.showInFiles(objectName());
 }
 
-MeltJob::MeltJob(const QString &name, const QString &xml, const QStringList &args, int frameRateNum,
+MeltJob::MeltJob(const QString &name,
+                 const QString &xml,
+                 const QStringList &args,
+                 int frameRateNum,
                  int frameRateDen)
     : MeltJob(name, xml, frameRateNum, frameRateDen)
 {
@@ -108,9 +117,7 @@ void MeltJob::start()
         AbstractJob::start();
         LOG_ERROR() << "the job XML is empty!";
         appendToLog("Error: the job XML is empty!\n");
-        QTimer::singleShot(0, this, [ = ]() {
-            emit finished(this, false);
-        });
+        QTimer::singleShot(0, this, [=]() { emit finished(this, false); });
         return;
     }
     QString shotcutPath = qApp->applicationDirPath();
@@ -140,7 +147,7 @@ void MeltJob::start()
     if (m_out > -1) {
         args << QStringLiteral("out=%1").arg(m_out);
     }
-    LOG_DEBUG() << meltPath.absoluteFilePath()  + " " + args.join(' ');
+    LOG_DEBUG() << meltPath.absoluteFilePath() + " " + args.join(' ');
 #ifndef Q_OS_MAC
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     // These environment variables fix rich text rendering for high DPI
@@ -150,17 +157,21 @@ void MeltJob::start()
     setProcessEnvironment(env);
 #endif
 #ifdef Q_OS_WIN
-    if (m_isStreaming) args << "-getc";
+    if (m_isStreaming)
+        args << "-getc";
 #endif
     AbstractJob::start(meltPath.absoluteFilePath(), args);
 }
 
 QString MeltJob::xml()
 {
-    m_xml->open();
-    QString s(m_xml->readAll());
-    m_xml->close();
-    return s;
+    if (m_xml->open()) {
+        QString s(m_xml->readAll());
+        m_xml->close();
+        return s;
+    } else {
+        return QString();
+    }
 }
 
 void MeltJob::setIsStreaming(bool streaming)
