@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2024 Meltytech, LLC
+ * Copyright (c) 2011-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 
 #include "transportcontrol.h"
 
+#include "settings.h"
+
 #include <Mlt.h>
 #include <QImage>
 #include <QMutex>
@@ -31,13 +33,8 @@
 #define MLT_LC_CATEGORY LC_ALL
 #define MLT_LC_NAME "LC_ALL"
 
-#if LIBMLT_VERSION_INT >= ((7 << 16) + (19 << 8))
 #define kAudioIndexProperty "astream"
 #define kVideoIndexProperty "vstream"
-#else
-#define kAudioIndexProperty "audio_index"
-#define kVideoIndexProperty "video_index"
-#endif
 
 namespace Mlt {
 
@@ -105,8 +102,10 @@ public:
     int consumerChanged();
     void setProfile(const QString &profile_name);
     void setAudioChannels(int audioChannels);
+    void setProcessingMode(ShotcutSettings::ProcessingMode mode);
     QString resource() const;
     bool isSeekable(Mlt::Producer *p = nullptr) const;
+    int maxFrameCount() const;
     bool isLiveProducer(Mlt::Producer *p = nullptr) const;
     bool isClip() const;
     bool isClosedClip(Producer *producer = nullptr) const;
@@ -115,6 +114,7 @@ public:
     bool isMultitrack() const;
     bool isImageProducer(Service *service) const;
     bool isFileProducer(Service *service) const;
+    static bool isProjectProducer(Service *service);
     void rewind(bool forceChangeDirection);
     void fastForward(bool forceChangeDirection);
     void previous(int currentPosition);
@@ -122,7 +122,7 @@ public:
     void setIn(int);
     void setOut(int);
     void fixLengthProperties(Service &service);
-    void restart(const QString &xml = "");
+    void reload(const QString &xml);
     void resetURL();
     QImage image(Frame *frame, int width, int height);
     QImage image(Mlt::Producer &producer, int frameNumber, int width, int height);
@@ -154,6 +154,7 @@ public:
     QString filtersClipboardXML() { return XML(m_filtersClipboard.get()); }
 
     int audioChannels() const { return m_audioChannels; }
+    ShotcutSettings::ProcessingMode processingMode() const { return m_processingMode; }
     Mlt::Repository *repository() const { return m_repo; }
     Mlt::Profile &profile() { return m_profile; }
     Mlt::Profile &previewProfile() { return m_previewProfile; }
@@ -164,6 +165,7 @@ public:
     Mlt::Producer *savedProducer() const { return m_savedProducer.data(); }
     void setSavedProducer(Mlt::Producer *producer);
     static Mlt::Filter *getFilter(const QString &name, Mlt::Service *service);
+    static Mlt::Link *getLink(const QString &name, Mlt::Service *service);
     QString projectFolder() const { return m_projectFolder; }
     void setProjectFolder(const QString &folderName);
     QChar decimalPoint();
@@ -195,6 +197,7 @@ private:
     Mlt::Profile m_profile;
     Mlt::Profile m_previewProfile;
     int m_audioChannels{2};
+    ShotcutSettings::ProcessingMode m_processingMode{ShotcutSettings::Native8Cpu};
     QScopedPointer<Mlt::Filter> m_jackFilter;
     QString m_url;
     double m_volume{1.0};
