@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2024 Meltytech, LLC
+ * Copyright (c) 2020-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,10 +120,7 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer,
                           ? producer.get_int(kDefaultAudioIndexProperty)
                           : producer.get_int("audio_index");
     if (producer.get_int("video_index") < audioIndex) {
-        // iPhone 16 Pro has a 4 channel (spatial) audio stream with codec "apac" that causes failure.
-        // This is not limited to only iPhone 16 Pro, but I think most iPhones only record one usable audio track.
-        if (!::qstrcmp(producer.get("meta.media.1.stream.type"), "audio")
-            && QString(producer.get("meta.attr.com.apple.quicktime.model.markup")).contains("iPhone"))
+        if (Util::hasiPhoneAmbisonic(&producer))
             args << "-map"
                  << "0:V?"
                  << "-map"
@@ -206,6 +203,12 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer,
         args << "-colorspace"
              << "bt470bg";
         break;
+    case 2020:
+        args << "-color_primaries"
+             << "bt2020";
+        args << "-colorspace"
+             << "bt2020nc";
+        break;
     default:
         args << "-color_primaries"
              << "bt709";
@@ -460,7 +463,7 @@ bool ProxyManager::filterXML(QString &xmlString, QString root)
 
     // This prevents processProperties() from mis-matching a resource path that begins with root
     // when it is converting to relative paths.
-    if (!root.isEmpty() && root.endsWith('/')) {
+    if (!root.isEmpty() && !root.endsWith('/')) {
         root.append('/');
     }
 
