@@ -16,10 +16,13 @@
  */
 
 #include "screencapture.h"
+#include "Logger.h"
 #include "rectangleselector.h"
 #include "toolbarwidget.h"
 #include "windowpicker.h"
 #include <QApplication>
+#include <QFileInfo>
+#include <QProcess>
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -42,6 +45,8 @@ ScreenCapture::ScreenCapture(const QString &outputFile, CaptureMode mode, QObjec
     , m_outputFile(outputFile)
     , m_mode(mode)
     , m_isImageMode(false)
+    , m_minimizeShotcut(false)
+    , m_recordAudio(false)
 {}
 
 ScreenCapture::~ScreenCapture() {}
@@ -59,11 +64,16 @@ void ScreenCapture::startRecording()
         startWindowRecording();
         break;
     case Interactive:
-        m_toolbar = std::make_unique<ToolbarWidget>();
+        m_toolbar = std::make_unique<ScreenCaptureToolbar>(true);
         // Toolbar emits int, convert to CaptureMode via lambda for Qt6 typed connect compatibility
-        connect(m_toolbar.get(), &ToolbarWidget::captureModeSelected, this, [this](int mode) {
-            this->onCaptureModeSelected(static_cast<CaptureMode>(mode));
-        });
+        connect(m_toolbar.get(),
+                &ScreenCaptureToolbar::captureModeSelected,
+                this,
+                [this](int mode, bool minimizeShotcut, bool recordAudio) {
+                    this->onCaptureModeSelected(static_cast<CaptureMode>(mode),
+                                                minimizeShotcut,
+                                                recordAudio);
+                });
         m_toolbar->show();
         break;
     }
@@ -85,16 +95,21 @@ void ScreenCapture::startSnapshot()
         break;
     case Interactive:
         // Show toolbar for user to choose mode
-        m_toolbar = std::make_unique<ToolbarWidget>();
-        connect(m_toolbar.get(), &ToolbarWidget::captureModeSelected, this, [this](int mode) {
-            this->onCaptureModeSelected(static_cast<CaptureMode>(mode));
-        });
+        m_toolbar = std::make_unique<ScreenCaptureToolbar>(false);
+        connect(m_toolbar.get(),
+                &ScreenCaptureToolbar::captureModeSelected,
+                this,
+                [this](int mode, bool minimizeShotcut, bool recordAudio) {
+                    this->onCaptureModeSelected(static_cast<CaptureMode>(mode),
+                                                minimizeShotcut,
+                                                recordAudio);
+                });
         m_toolbar->show();
         break;
     }
 }
 
-void ScreenCapture::onCaptureModeSelected(CaptureMode mode)
+void ScreenCapture::onCaptureModeSelected(CaptureMode mode, bool minimizeShotcut, bool recordAudio)
 {
     // Close the toolbar safely after signal processing completes
     if (m_toolbar) {
@@ -104,6 +119,13 @@ void ScreenCapture::onCaptureModeSelected(CaptureMode mode)
     }
 
     m_mode = mode;
+    m_minimizeShotcut = minimizeShotcut;
+    m_recordAudio = recordAudio;
+
+    // Emit minimize signal if requested
+    if (m_minimizeShotcut) {
+        emit this->minimizeShotcut();
+    }
 
     // Continue with the selected mode, respecting image vs video
     if (m_isImageMode) {
@@ -128,7 +150,7 @@ void ScreenCapture::onRectangleSelected(const QRect &rect)
     if (screen)
         newRect &= applyDevicePixelRatio(screen->geometry());
 
-    emit beginRecording(adjustRectForVideo(newRect));
+    emit beginRecording(adjustRectForVideo(newRect), m_recordAudio);
 }
 
 void ScreenCapture::onWindowSelected(const QRect &rect)
@@ -148,14 +170,14 @@ void ScreenCapture::onWindowSelected(const QRect &rect)
     if (screen)
         newRect &= applyDevicePixelRatio(screen->geometry());
 
-    emit beginRecording(adjustRectForVideo(newRect));
+    emit beginRecording(adjustRectForVideo(newRect), m_recordAudio);
 }
 
 void ScreenCapture::startFullscreenRecording()
 {
     QScreen *screen = QGuiApplication::primaryScreen();
     if (!screen) {
-        qCritical() << "Error: No screen found";
+        LOG_ERROR() << "Error: No screen found";
         return;
     }
 
@@ -163,7 +185,7 @@ void ScreenCapture::startFullscreenRecording()
     if (!isWayland() || !qEnvironmentVariable("XDG_CURRENT_DESKTOP").toLower().contains("gnome"))
         physicalRect = applyDevicePixelRatio(screen->geometry());
 
-    emit beginRecording(adjustRectForVideo(physicalRect));
+    emit beginRecording(adjustRectForVideo(physicalRect), m_recordAudio);
 }
 
 void ScreenCapture::startRectangleRecording()
@@ -183,7 +205,7 @@ void ScreenCapture::startRectangleRecording()
 void ScreenCapture::startWindowRecording()
 {
     if (isWayland()) {
-        qCritical() << "Window capture is not supported on Wayland";
+        LOG_ERROR() << "Window capture is not supported on Wayland";
         return;
     }
     m_windowPicker = std::make_unique<WindowPicker>();
@@ -206,18 +228,75 @@ QPixmap ScreenCapture::captureScreen(const QRect &rect)
 
 void ScreenCapture::startFullscreenSnapshot()
 {
+#ifdef Q_OS_MAC
+    // Use native macOS screencapture command for fullscreen
+    QStringList args;
+    args << "-S" // Fullscreen
+         << "-t"
+         << "png" << m_outputFile;
+
+    QProcess *process = new QProcess(this);
+    connect(process, &QProcess::finished, this, [=](int exitCode, QProcess::ExitStatus) {
+        const bool success = (exitCode == 0 && QFileInfo::exists(m_outputFile));
+
+        if (!success) {
+            LOG_ERROR() << "Failed to capture fullscreen snapshot";
+            QString stdoutData = QString::fromUtf8(process->readAllStandardOutput());
+            QString stderrData = QString::fromUtf8(process->readAllStandardError());
+            if (!stdoutData.isEmpty()) {
+                LOG_INFO() << "stdout:" << stdoutData;
+            }
+            if (!stderrData.isEmpty()) {
+                LOG_INFO() << "stderr:" << stderrData;
+            }
+        }
+        process->deleteLater();
+        emit finished(success);
+    });
+
+    process->start("screencapture", args);
+#else
     QScreen *screen = QGuiApplication::primaryScreen();
     if (!screen) {
-        qCritical() << "Error: No screen found";
+        LOG_ERROR() << "Error: No screen found";
         return;
     }
 
     // Small delay to let any UI elements disappear
     QTimer::singleShot(100, this, [this, screen]() { captureAndSaveImage(screen->geometry()); });
+#endif
 }
 
 void ScreenCapture::startRectangleSnapshot()
 {
+#ifdef Q_OS_MAC
+    // Use native macOS screencapture command with rectangle selection
+    QStringList args;
+    args << "-i"
+         << "-t"
+         << "png" << m_outputFile;
+
+    QProcess *process = new QProcess(this);
+    connect(process, &QProcess::finished, this, [=](int exitCode, QProcess::ExitStatus) {
+        const bool success = (exitCode == 0 && QFileInfo::exists(m_outputFile));
+
+        if (!success) {
+            LOG_ERROR() << "Failed to capture rectangle snapshot";
+            QString stdoutData = QString::fromUtf8(process->readAllStandardOutput());
+            QString stderrData = QString::fromUtf8(process->readAllStandardError());
+            if (!stdoutData.isEmpty()) {
+                LOG_INFO() << "stdout:" << stdoutData;
+            }
+            if (!stderrData.isEmpty()) {
+                LOG_INFO() << "stderr:" << stderrData;
+            }
+        }
+        process->deleteLater();
+        emit finished(success);
+    });
+
+    process->start("screencapture", args);
+#else
     m_rectangleSelector = std::make_unique<RectangleSelector>();
     connect(m_rectangleSelector.get(),
             &RectangleSelector::rectangleSelected,
@@ -228,12 +307,41 @@ void ScreenCapture::startRectangleSnapshot()
             this,
             &ScreenCapture::onSelectionCanceled);
     m_rectangleSelector->show();
+#endif
 }
 
 void ScreenCapture::startWindowSnapshot()
 {
+#ifdef Q_OS_MAC
+    // Use native macOS screencapture command with window selection
+    QStringList args;
+    args << "-W"
+         << "-t"
+         << "png" << m_outputFile;
+
+    QProcess *process = new QProcess(this);
+    connect(process, &QProcess::finished, this, [=](int exitCode, QProcess::ExitStatus) {
+        const bool success = (exitCode == 0 && QFileInfo::exists(m_outputFile));
+
+        if (!success) {
+            LOG_ERROR() << "Failed to capture window snapshot";
+            QString stdoutData = QString::fromUtf8(process->readAllStandardOutput());
+            QString stderrData = QString::fromUtf8(process->readAllStandardError());
+            if (!stdoutData.isEmpty()) {
+                LOG_INFO() << "stdout:" << stdoutData;
+            }
+            if (!stderrData.isEmpty()) {
+                LOG_INFO() << "stderr:" << stderrData;
+            }
+        }
+        process->deleteLater();
+        emit finished(success);
+    });
+
+    process->start("screencapture", args);
+#else
     if (isWayland()) {
-        qCritical() << "Window image capture is not supported on Wayland";
+        LOG_ERROR() << "Window image capture is not supported on Wayland";
         return;
     }
     m_windowPicker = std::make_unique<WindowPicker>();
@@ -242,6 +350,7 @@ void ScreenCapture::startWindowSnapshot()
             this,
             &ScreenCapture::onImageWindowSelected);
     m_windowPicker->show();
+#endif
 }
 
 void ScreenCapture::onImageRectangleSelected(const QRect &rect)
@@ -293,41 +402,37 @@ void ScreenCapture::captureAndSaveImage(const QRect &rect)
     }
 
     // Defer a bit so the window manager/compositor has time to unmap our UI
-    // before the portal snapshot is taken.
-    if (isWayland()) {
-        QTimer::singleShot(120, this, [this, rect]() { doCaptureAndSaveImage(rect); });
-    } else {
-        doCaptureAndSaveImage(rect);
-    }
+    // before the snapshot is taken.
+    QTimer::singleShot(120, this, [this, rect]() { doCaptureAndSaveImage(rect); });
 }
 
 void ScreenCapture::doCaptureAndSaveImage(const QRect &rect)
 {
-    qDebug() << "Capturing image:" << rect;
-    qDebug() << "Output file:" << m_outputFile;
+    LOG_DEBUG() << "Capturing image:" << rect;
+    LOG_DEBUG() << "Output file:" << m_outputFile;
 
     if (isWayland()) {
         // Try xdg-desktop-portal first (permission prompt)
         if (captureImagePortal(rect, m_outputFile)) {
-            qDebug() << "Image saved successfully to:" << m_outputFile;
+            LOG_DEBUG() << "Image saved successfully to:" << m_outputFile;
             emit finished(true);
             return;
         }
-        qWarning() << "Portal screenshot failed, will try Qt grabWindow next.";
+        LOG_WARNING() << "Portal screenshot failed, will try Qt grabWindow next.";
     }
 
     QPixmap pixmap = captureScreen(rect);
     if (pixmap.isNull()) {
-        qCritical() << "Failed to capture screen";
+        LOG_ERROR() << "Failed to capture screen";
         emit finished(false);
         return;
     }
 
     if (pixmap.save(m_outputFile)) {
-        qDebug() << "Image saved successfully to:" << m_outputFile;
+        LOG_DEBUG() << "Image saved successfully to:" << m_outputFile;
         emit finished(true);
     } else {
-        qCritical() << "Failed to save image to:" << m_outputFile;
+        LOG_ERROR() << "Failed to save image to:" << m_outputFile;
         emit finished(false);
     }
 }
@@ -337,7 +442,7 @@ bool ScreenCapture::captureImagePortal(const QRect &rect, const QString &outputP
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
     auto bus = QDBusConnection::sessionBus();
     if (!bus.isConnected()) {
-        qWarning() << "DBus session bus not connected";
+        LOG_WARNING() << "DBus session bus not connected";
         return false;
     }
 
@@ -364,13 +469,13 @@ bool ScreenCapture::captureImagePortal(const QRect &rect, const QString &outputP
 
     QDBusPendingReply<QDBusObjectPath> reply = watcher.reply();
     if (reply.isError()) {
-        qWarning() << "Portal Screenshot call failed:" << reply.error().message();
+        LOG_WARNING() << "Portal Screenshot call failed:" << reply.error().message();
         return false;
     }
 
     const auto handlePath = reply.value();
     if (handlePath.path().isEmpty()) {
-        qWarning() << "Portal returned empty handle";
+        LOG_WARNING() << "Portal returned empty handle";
         return false;
     }
 
@@ -387,7 +492,7 @@ bool ScreenCapture::captureImagePortal(const QRect &rect, const QString &outputP
                           this,
                           SLOT(onPortalResponse(uint, QVariantMap)));
     if (!ok) {
-        qWarning() << "Failed to connect to portal Response signal";
+        LOG_WARNING() << "Failed to connect to portal Response signal";
         m_portalEventLoop = nullptr;
         return false;
     }
@@ -406,14 +511,14 @@ bool ScreenCapture::captureImagePortal(const QRect &rect, const QString &outputP
                    SLOT(onPortalResponse(uint, QVariantMap)));
 
     if (!m_portalSuccess) {
-        qWarning() << "Portal screenshot failed or timed out";
+        LOG_WARNING() << "Portal screenshot failed or timed out";
         return false;
     }
 
     QUrl url(m_portalUri);
     QString srcPath = url.isValid() && url.scheme() == "file" ? url.toLocalFile() : m_portalUri;
     if (srcPath.isEmpty()) {
-        qWarning() << "Portal provided empty source path";
+        LOG_WARNING() << "Portal provided empty source path";
         return false;
     }
 
@@ -421,7 +526,7 @@ bool ScreenCapture::captureImagePortal(const QRect &rect, const QString &outputP
         QFile::remove(outputPath);
     }
     if (!QFile::copy(srcPath, outputPath)) {
-        qWarning() << "Failed to copy portal image from" << srcPath << "to" << outputPath;
+        LOG_WARNING() << "Failed to copy portal image from" << srcPath << "to" << outputPath;
         return false;
     }
 #endif
@@ -435,7 +540,7 @@ void ScreenCapture::onPortalResponse(uint response, const QVariantMap &results)
         m_portalSuccess = !m_portalUri.isEmpty();
     } else {
         m_portalSuccess = false;
-        qWarning() << "Portal responded with error code" << response;
+        LOG_WARNING() << "Portal responded with error code" << response;
     }
     if (m_portalEventLoop) {
         m_portalEventLoop->quit();
@@ -464,8 +569,8 @@ QRect ScreenCapture::adjustRectForVideo(const QRect &rect)
 
     auto result = QRect(rect.x(), rect.y(), width, height);
     if (result != rect)
-        qDebug() << "Adjusted capture area from" << rect << "to" << result
-                 << "(H.264 requires even dimensions)";
+        LOG_DEBUG() << "Adjusted capture area from" << rect << "to" << result
+                    << "(H.264 requires even dimensions)";
     return result;
 }
 
@@ -474,7 +579,7 @@ QRect ScreenCapture::applyDevicePixelRatio(const QRect &rect)
     // Get the device pixel ratio from the primary screen
     QScreen *screen = QGuiApplication::primaryScreen();
     if (!screen) {
-        qWarning() << "Could not get screen for device pixel ratio";
+        LOG_WARNING() << "Could not get screen for device pixel ratio";
         return rect;
     }
 
@@ -492,9 +597,9 @@ QRect ScreenCapture::applyDevicePixelRatio(const QRect &rect)
 
     QRect logicalRect(logicalX, logicalY, logicalWidth, logicalHeight);
 
-    qDebug() << "Device Pixel Ratio:" << dpr;
-    qDebug() << "Physical rect (from selector):" << rect;
-    qDebug() << "Logical rect (for grabWindow):" << logicalRect;
+    LOG_DEBUG() << "Device Pixel Ratio:" << dpr;
+    LOG_DEBUG() << "Physical rect (from selector):" << rect;
+    LOG_DEBUG() << "Logical rect (for grabWindow):" << logicalRect;
 
     return logicalRect;
 }
@@ -504,7 +609,7 @@ QRect ScreenCapture::invertDevicePixelRatio(const QRect &rect)
     // Get the device pixel ratio from the primary screen
     QScreen *screen = QGuiApplication::primaryScreen();
     if (!screen) {
-        qWarning() << "Could not get screen for device pixel ratio";
+        LOG_WARNING() << "Could not get screen for device pixel ratio";
         return rect;
     }
 
@@ -522,9 +627,9 @@ QRect ScreenCapture::invertDevicePixelRatio(const QRect &rect)
 
     QRect logicalRect(logicalX, logicalY, logicalWidth, logicalHeight);
 
-    qDebug() << "Device Pixel Ratio:" << dpr;
-    qDebug() << "Physical rect (from selector):" << rect;
-    qDebug() << "Logical rect (for grabWindow):" << logicalRect;
+    LOG_DEBUG() << "Device Pixel Ratio:" << dpr;
+    LOG_DEBUG() << "Physical rect (from selector):" << rect;
+    LOG_DEBUG() << "Logical rect (for grabWindow):" << logicalRect;
 
     return logicalRect;
 }
