@@ -58,6 +58,10 @@ AvformatProducerWidget::AvformatProducerWidget(QWidget *parent)
     ui->setupUi(this);
     ui->timelineDurationText->setFixedWidth(ui->durationSpinBox->width());
     ui->filenameLabel->setFrame(true);
+#ifndef EXTERNAL_LAUNCHERS
+    delete ui->openWithButton;
+#endif
+
     Util::setColorsToHighlight(ui->filenameLabel, QPalette::Base);
     connect(ui->applySpeedButton, SIGNAL(clicked()), SLOT(on_speedSpinBox_editingFinished()));
     connect(this,
@@ -399,6 +403,8 @@ void AvformatProducerWidget::reloadProducerValues()
                     break;
                 case 9:
                 case 10:
+                case 2020:
+                case 2021:
                     csString = "ITU-R BT.2020";
                     break;
                 }
@@ -1224,7 +1230,7 @@ void AvformatProducerWidget::on_actionExtractSubtitles_triggered()
     for (int i = 0; i < nb_streams; i++) {
         QString key = QStringLiteral("meta.media.%1.codec.name").arg(i);
         QString codec(m_producer->get(key.toLatin1().constData()));
-        if (codec == "srt") {
+        if (codec == "srt" || codec == "mov_text" || codec == "ssa") {
             subtitleCount++;
             QString langKey = QStringLiteral("meta.attr.%1.stream.language.markup").arg(i);
             QString lang(m_producer->get(langKey.toLatin1().constData()));
@@ -1235,7 +1241,7 @@ void AvformatProducerWidget::on_actionExtractSubtitles_triggered()
             }
         }
     }
-    QString caption = tr("Export Subtitles...");
+    QString caption = tr("Extract Subtitles...");
     if (subtitles.size() <= 0) {
         QMessageBox::warning(this, caption, tr("No subtitles found"));
         return;
@@ -1273,7 +1279,7 @@ void AvformatProducerWidget::on_actionExtractSubtitles_triggered()
         for (int i = 0; i < nb_streams; i++) {
             QString key = QStringLiteral("meta.media.%1.codec.name").arg(i);
             QString codec(m_producer->get(key.toLatin1().constData()));
-            if (codec == "srt") {
+            if (codec == "srt" || codec == "mov_text" || codec == "ssa") {
                 subtitleCount++;
                 QString subText;
                 QString langKey = QStringLiteral("meta.attr.%1.stream.language.markup").arg(i);
@@ -1624,7 +1630,7 @@ void AvformatProducerWidget::on_openWithButton_clicked()
     for (const auto &program : programs) {
         auto action = menu.addAction(QFileInfo(program).baseName(), this, [=]() {
             LOG_DEBUG() << program << filePath;
-            if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+            if (Util::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
                 m_watcher.reset(new QFileSystemWatcher({filePath}));
                 connect(m_watcher.get(),
                         &QFileSystemWatcher::fileChanged,
@@ -1658,7 +1664,7 @@ void AvformatProducerWidget::onOpenOtherAdd()
     const auto program = Util::getExecutable(&MAIN);
     if (!program.isEmpty()) {
         LOG_DEBUG() << program << filePath;
-        if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+        if (Util::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
             Settings.setFilesOpenOther(mediaType(), program);
             m_watcher.reset(new QFileSystemWatcher({filePath}));
             connect(m_watcher.get(),
